'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _forEach = require('lodash/collection/forEach');

var _forEach2 = _interopRequireDefault(_forEach);

var _flatten = require('lodash/array/flatten');

var _flatten2 = _interopRequireDefault(_flatten);

var _map = require('lodash/collection/map');

var _map2 = _interopRequireDefault(_map);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var apply = undefined,
    isMemoryFileSystem = undefined;

/**
 * When 'webpack' program is used, constructor name is equal to 'NodeOutputFileSystem'.
 * When 'webpack-dev-server' program is used, constructor name is equal to 'MemoryFileSystem'.
 *
 * @param {Object} outputFileSystem
 * @returns {boolean}
 */
isMemoryFileSystem = function (outputFileSystem) {
    return outputFileSystem.constructor.name === 'MemoryFileSystem';
};

apply = function (compiler) {
    compiler.plugin('done', function (stats) {
        var files = undefined,
            outputPath = undefined;

        if (!isMemoryFileSystem(compiler.outputFileSystem)) {
            return;
        }

        if (stats.compilation.errors.length) {
            return;
        }

        if (!compiler.options.devServer.outputPath) {
            throw new Error('devServer.outputPath is not defined.');
        }

        outputPath = compiler.options.devServer.outputPath;

        _mkdirp2.default.sync(outputPath);

        files = (0, _map2.default)(stats.compilation.chunks, 'files');
        files = (0, _flatten2.default)(files);

        (0, _forEach2.default)(files, function (bundleFileName) {
            var bundleBody = undefined,
                bundleFilePath = undefined,
                outputFilePath = undefined;

            bundleFilePath = _path2.default.join('/', bundleFileName);
            bundleBody = compiler.outputFileSystem.readFileSync(bundleFilePath);
            outputFilePath = _path2.default.join(outputPath, bundleFileName);

            _fs2.default.writeFileSync(outputFilePath, bundleBody);
        });
    });
};

exports.default = function () {
    return {
        apply: apply
    };
};
//# sourceMappingURL=index.js.map
